==> enterprisemodules-ora_config-3.23.4.tar.gz: enterprisemodules-ora_config-3.23.4/lib/puppet/type/ora_rman_config/datafile_backup_copies.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:datafile_backup_copies) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `DATAFILE BACKUP COPIES`.
    The configuration can be set to default by setting the device type to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      datafile_backup_copies => {
        'DISK' => '2',
        'SBT'  => 'CLEAR',
      },
      ...
    }
  DESC

  data_type("Optional[Hash[Enum['DISK','SBT'],String[1]]]")

  to_translate_to_resource do |raw_resource|
    raw_resource['DATAFILE_BACKUP_COPIES']
  end

  def insync?(is)
    return true if is == should

    checkdiff(is, should).empty?
  end

  def change_to_s(currentvalue, newvalue)
    diff = checkdiff(currentvalue, newvalue)
    messages = []
    diff.each_pair do |type, val|
      messages << if val.casecmp('clear').zero?
                    "clearing datafile_backup_copies for device type #{type}"
                  else
                    "changing datafile_backup_copies for device type #{type} to #{val}"
                  end
    end
    messages.join(', ')
  end

  on_modify do
    diff = checkdiff(provider.datafile_backup_copies, should)
    diff.each_pair do |type, val|
      if val.to_s.casecmp('clear').zero?
        rman("configure datafile backup copies for device type #{type} #{val}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
      else
        rman("configure datafile backup copies for device type #{type} to #{val}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
      end
    end
  end

  def checkdiff(is, should)
    my_should = should
    my_should.each_pair do |key, val|
      if val.to_s.casecmp('clear').zero?
        my_should.delete(key) if is[key].to_s.include?('(default)') || is[key].nil?
      elsif is[key].to_s.casecmp(val.to_s).zero?
        my_should.delete(key)
      end
    end
  end
end

==> enterprisemodules-ora_config-3.26.2.tar.gz: enterprisemodules-ora_config-3.26.2/lib/puppet/type/ora_rman_config/datafile_backup_copies.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:datafile_backup_copies) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `DATAFILE BACKUP COPIES`.
    The configuration can be set to default by setting the device type to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      datafile_backup_copies => {
        'DISK' => '2',
        'SBT'  => 'CLEAR',
      },
      ...
    }
  DESC

  data_type("Optional[Hash[Enum['DISK','SBT'],String[1]]]")

  to_translate_to_resource do |raw_resource|
    raw_resource['DATAFILE_BACKUP_COPIES']
  end

  def insync?(is)
    return true if is == should

    checkdiff(is, should).empty?
  end

  def change_to_s(currentvalue, newvalue)
    diff = checkdiff(currentvalue, newvalue)
    messages = []
    diff.each_pair do |type, val|
      messages << if val.casecmp('clear')&.zero?
                    "clearing datafile_backup_copies for device type #{type}"
                  else
                    "changing datafile_backup_copies for device type #{type} to #{val}"
                  end
    end
    messages.join(', ')
  end

  on_modify do
    diff = checkdiff(provider.datafile_backup_copies, should)
    diff.each_pair do |type, val|
      if val.to_s.casecmp('clear')&.zero?
        rman("configure datafile backup copies for device type #{type} #{val}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
      else
        rman("configure datafile backup copies for device type #{type} to #{val}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
      end
    end
  end

  def checkdiff(is, should)
    my_should = should
    my_should.each_pair do |key, val|
      if val.to_s.casecmp('clear')&.zero?
        my_should.delete(key) if is[key].to_s.include?('(default)') || is[key].nil?
      elsif is[key].to_s.casecmp(val.to_s)&.zero?
        my_should.delete(key)
      end
    end
  end
end
